# Generated by roxygen2: do not edit by hand

S3method(CMHtest,default)
S3method(CMHtest,formula)
S3method(LRstats,default)
S3method(LRstats,glmlist)
S3method(LRstats,loglmlist)
S3method(Summarise,default)
S3method(Summarise,glmlist)
S3method(Summarise,loglmlist)
S3method(assoc,glm)
S3method(assoc_graph,glm)
S3method(assoc_graph,list)
S3method(assoc_graph,loglm)
S3method(coef,glmlist)
S3method(color_table,data.frame)
S3method(color_table,default)
S3method(color_table,ftable)
S3method(color_table,matrix)
S3method(color_table,structable)
S3method(color_table,table)
S3method(drop1,loglm)
S3method(logLik,loglm)
S3method(logist_plot,data.frame)
S3method(logist_plot,default)
S3method(logist_plot,formula)
S3method(modFit,glm)
S3method(modFit,loglm)
S3method(mosaic,glm)
S3method(mosaic,glmlist)
S3method(mosaic,loglmlist)
S3method(mosaic3d,default)
S3method(mosaic3d,loglm)
S3method(pairs,table)
S3method(plot,HLtest)
S3method(plot,assoc_graph)
S3method(print,CMHtest)
S3method(print,GKgamma)
S3method(print,HLtest)
S3method(print,Kappa)
S3method(print,assoc_graph)
S3method(print,breslow_day_test)
S3method(print,woolf_test)
S3method(rootogram,HLtest)
S3method(sieve,glm)
S3method(split3d,list)
S3method(split3d,shape3d)
S3method(summary,HLtest)
S3method(update,xtabs)
export(CMHtest)
export(Crossings)
export(GKgamma)
export(HLtest)
export(Kway)
export(LRanova)
export(LRstats)
export(Summarise)
export(as_array)
export(as_caseform)
export(as_freqform)
export(as_matrix)
export(as_table)
export(assoc_graph)
export(assoc_strength)
export(blogits)
export(breslow_day_test)
export(center3d)
export(collapse.table)
export(collapse_levels)
export(color_table)
export(conditional)
export(cutfac)
export(datasets)
export(dlogseries)
export(drop1.loglm)

export(expand.dft)
export(expand.table)
export(get_model)
export(get_models)
export(glmlist)
export(joint)
export(knit_include)
export(labeling_points)
export(logist_density)
export(logist_hist)
export(logist_plot)
export(logist_point)
export(loglin2formula)
export(loglin2string)
export(loglmlist)
export(markov)
export(mcaplot)
export(modFit)
export(mosaic3d)
export(mutual)
export(pairs_diagonal_mosaic)
export(plogseries)
export(qlogseries)
export(range3d)
export(rlogseries)
export(saturated)
export(seq_loglm)
export(seq_mosaic)
export(split3d)
export(update.xtabs)
export(woolf_test)
export(zero.test)
importFrom(MASS,loglm)
importFrom(ca,
  cacoord,
  multilines
)
importFrom(dplyr,
  all_of,
  as_tibble,
  everything,
  is.tbl,
  rename,
  summarise
)
importFrom(forcats,fct_collapse)
importFrom(gnm,meanResiduals)
importFrom(grDevices,
  col2rgb,
  hsv,
  rgb
)
importFrom(graphics,
  abline,
  plot,
  points,
  text
)
importFrom(grid,
  gpar,
  grid.layout,
  grid.newpage,
  grid.points,
  popViewport,
  pushViewport,
  seekViewport,
  unit,
  upViewport,
  viewport
)
importFrom(htmlwidgets,saveWidget)
importFrom(knitr,
  include_graphics,
  is_html_output
)
importFrom(methods,is)
importFrom(rlang,
  .data,
  set_names
)
importFrom(stats,
  as.formula,
  chisq.test,
  deviance,
  family,
  fitted,
  formula,
  glm,
  logLik,
  loglin,
  mantelhaen.test,
  model.frame,
  na.pass,
  nobs,
  pchisq,
  poisson,
  qnorm,
  quantile,
  reformulate,
  residuals,
  rstandard,
  runif,
  setNames,
  terms,
  update,
  update.formula,
  weighted.mean,
  xtabs
)
importFrom(utils,
  data,
  menu,
  type.convert
)
importFrom(vcd,
  assoc,
  assocstats,
  is.structable,
  labeling_border,
  labeling_values,
  mosaic,
  rootogram,
  shading_hcl,
  sieve
)
importFrom(webshot2,webshot)
