#' Deprecated functions in vcdExtra
#'
#' These functions are provided for compatibility with older versions of
#' vcdExtra and will be removed in a future release.
#'
#' \itemize{
#'   \item [Summarise()] is deprecated in favor of [LRstats()], which provides
#'     the same brief model-fit comparison under a name that doesn't
#'     near-collide with `dplyr::summarise()`.
#' }
#'
#' @name vcdExtra-deprecated
#' @keywords internal
NULL
