% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vcdExtra-deprecated.R
\name{vcdExtra-deprecated}
\alias{vcdExtra-deprecated}
\title{Deprecated functions in vcdExtra}
\description{
These functions are provided for compatibility with older versions of
vcdExtra and will be removed in a future release.
}
\details{
\itemize{
\item \code{\link[=Summarise]{Summarise()}} is deprecated in favor of \code{\link[=LRstats]{LRstats()}}, which provides
the same brief model-fit comparison under a name that doesn't
near-collide with \code{dplyr::summarise()}.
}
}
\keyword{internal}
